hstrat.hstrat.HereditaryStratigraphicColumn
===========================================

.. currentmodule:: hstrat.hstrat

.. autoclass:: HereditaryStratigraphicColumn

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~HereditaryStratigraphicColumn.CalcDefinitiveMaxRankOfFirstRetainedDisparityWith
      ~HereditaryStratigraphicColumn.CalcDefinitiveMaxRankOfLastRetainedCommonalityWith
      ~HereditaryStratigraphicColumn.CalcDefinitiveMinRanksSinceFirstRetainedDisparityWith
      ~HereditaryStratigraphicColumn.CalcDefinitiveMinRanksSinceLastRetainedCommonalityWith
      ~HereditaryStratigraphicColumn.CalcMinImplausibleSpuriousConsecutiveDifferentiaCollisions
      ~HereditaryStratigraphicColumn.CalcProbabilityDifferentiaCollision
      ~HereditaryStratigraphicColumn.CalcRankOfEarliestDetectableMrcaWith
      ~HereditaryStratigraphicColumn.CalcRankOfFirstRetainedDisparityWith
      ~HereditaryStratigraphicColumn.CalcRankOfLastRetainedCommonalityWith
      ~HereditaryStratigraphicColumn.CalcRankOfMrcaBoundsWith
      ~HereditaryStratigraphicColumn.CalcRankOfMrcaUncertaintyWith
      ~HereditaryStratigraphicColumn.CalcRanksSinceEarliestDetectableMrcaWith
      ~HereditaryStratigraphicColumn.CalcRanksSinceFirstRetainedDisparityWith
      ~HereditaryStratigraphicColumn.CalcRanksSinceLastRetainedCommonalityWith
      ~HereditaryStratigraphicColumn.CalcRanksSinceMrcaBoundsWith
      ~HereditaryStratigraphicColumn.CalcRanksSinceMrcaUncertaintyWith
      ~HereditaryStratigraphicColumn.Clone
      ~HereditaryStratigraphicColumn.CloneDescendant
      ~HereditaryStratigraphicColumn.DefinitivelySharesNoCommonAncestorWith
      ~HereditaryStratigraphicColumn.DepositStratum
      ~HereditaryStratigraphicColumn.DiffRetainedRanks
      ~HereditaryStratigraphicColumn.GetColumnIndexOfRank
      ~HereditaryStratigraphicColumn.GetLastCommonStratumWith
      ~HereditaryStratigraphicColumn.GetNthCommonRankWith
      ~HereditaryStratigraphicColumn.GetNumDiscardedStrata
      ~HereditaryStratigraphicColumn.GetNumStrataDeposited
      ~HereditaryStratigraphicColumn.GetNumStrataRetained
      ~HereditaryStratigraphicColumn.GetRankAtColumnIndex
      ~HereditaryStratigraphicColumn.GetRetainedRanks
      ~HereditaryStratigraphicColumn.GetStratumAtColumnIndex
      ~HereditaryStratigraphicColumn.HasAnyCommonAncestorWith
      ~HereditaryStratigraphicColumn.HasDiscardedStrata
      ~HereditaryStratigraphicColumn.__init__
   
   

   
   
   